@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,17 +20,16 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.appengine_admin_v1.services.authorized_certificates import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import certificate
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AuthorizedCertificatesTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
 from .client import AuthorizedCertificatesClient
@@ -55,24 +52,20 @@ class AuthorizedCertificatesAsyncClient:
     parse_common_billing_account_path = staticmethod(
         AuthorizedCertificatesClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(AuthorizedCertificatesClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         AuthorizedCertificatesClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         AuthorizedCertificatesClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         AuthorizedCertificatesClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(AuthorizedCertificatesClient.common_project_path)
     parse_common_project_path = staticmethod(
         AuthorizedCertificatesClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         AuthorizedCertificatesClient.common_location_path
     )
@@ -82,7 +75,8 @@ class AuthorizedCertificatesAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -97,7 +91,7 @@ class AuthorizedCertificatesAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -114,7 +108,7 @@ class AuthorizedCertificatesAsyncClient:
 
     @property
     def transport(self) -> AuthorizedCertificatesTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             AuthorizedCertificatesTransport: The transport used by the client instance.
@@ -129,12 +123,12 @@ class AuthorizedCertificatesAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, AuthorizedCertificatesTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the authorized certificates client.
+        """Instantiates the authorized certificates client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -166,7 +160,6 @@ class AuthorizedCertificatesAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = AuthorizedCertificatesClient(
             credentials=credentials,
             transport=transport,
@@ -189,7 +182,6 @@ class AuthorizedCertificatesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest`):
                 The request object. Request message for
                 `AuthorizedCertificates.ListAuthorizedCertificates`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -206,7 +198,6 @@ class AuthorizedCertificatesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.ListAuthorizedCertificatesRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -249,7 +240,6 @@ class AuthorizedCertificatesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest`):
                 The request object. Request message for
                 `AuthorizedCertificates.GetAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -266,7 +256,6 @@ class AuthorizedCertificatesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetAuthorizedCertificateRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -303,7 +292,6 @@ class AuthorizedCertificatesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest`):
                 The request object. Request message for
                 `AuthorizedCertificates.CreateAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -320,7 +308,6 @@ class AuthorizedCertificatesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.CreateAuthorizedCertificateRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -362,7 +349,6 @@ class AuthorizedCertificatesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest`):
                 The request object. Request message for
                 `AuthorizedCertificates.UpdateAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -379,7 +365,6 @@ class AuthorizedCertificatesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.UpdateAuthorizedCertificateRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -416,7 +401,6 @@ class AuthorizedCertificatesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest`):
                 The request object. Request message for
                 `AuthorizedCertificates.DeleteAuthorizedCertificate`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -424,7 +408,6 @@ class AuthorizedCertificatesAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DeleteAuthorizedCertificateRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
