@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation as gac_operation  # type: ignore
@@ -34,8 +32,7 @@ from google.cloud.appengine_admin_v1.services.domain_mappings import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import domain_mapping
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .transports.base import DomainMappingsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import DomainMappingsGrpcAsyncIOTransport
 from .client import DomainMappingsClient
@@ -55,24 +52,20 @@ class DomainMappingsAsyncClient:
     parse_common_billing_account_path = staticmethod(
         DomainMappingsClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(DomainMappingsClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         DomainMappingsClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         DomainMappingsClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         DomainMappingsClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(DomainMappingsClient.common_project_path)
     parse_common_project_path = staticmethod(
         DomainMappingsClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(DomainMappingsClient.common_location_path)
     parse_common_location_path = staticmethod(
         DomainMappingsClient.parse_common_location_path
@@ -80,7 +73,8 @@ class DomainMappingsAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -95,7 +89,7 @@ class DomainMappingsAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -112,7 +106,7 @@ class DomainMappingsAsyncClient:
 
     @property
     def transport(self) -> DomainMappingsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             DomainMappingsTransport: The transport used by the client instance.
@@ -126,12 +120,12 @@ class DomainMappingsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, DomainMappingsTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the domain mappings client.
+        """Instantiates the domain mappings client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -163,7 +157,6 @@ class DomainMappingsAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = DomainMappingsClient(
             credentials=credentials,
             transport=transport,
@@ -185,7 +178,6 @@ class DomainMappingsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest`):
                 The request object. Request message for
                 `DomainMappings.ListDomainMappings`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -201,7 +193,6 @@ class DomainMappingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.ListDomainMappingsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -244,7 +235,6 @@ class DomainMappingsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetDomainMappingRequest`):
                 The request object. Request message for
                 `DomainMappings.GetDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -258,7 +248,6 @@ class DomainMappingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetDomainMappingRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -298,7 +287,6 @@ class DomainMappingsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest`):
                 The request object. Request message for
                 `DomainMappings.CreateDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -315,7 +303,6 @@ class DomainMappingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.CreateDomainMappingRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -364,7 +351,6 @@ class DomainMappingsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest`):
                 The request object. Request message for
                 `DomainMappings.UpdateDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -381,7 +367,6 @@ class DomainMappingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.UpdateDomainMappingRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -428,7 +413,6 @@ class DomainMappingsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest`):
                 The request object. Request message for
                 `DomainMappings.DeleteDomainMapping`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -455,7 +439,6 @@ class DomainMappingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DeleteDomainMappingRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -479,7 +462,7 @@ class DomainMappingsAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=ga_operation.OperationMetadataV1,
         )
 
