@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,16 +20,15 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.appengine_admin_v1.services.firewall import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import firewall
-
 from .transports.base import FirewallTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import FirewallGrpcAsyncIOTransport
 from .client import FirewallClient
@@ -62,24 +59,21 @@ class FirewallAsyncClient:
     parse_common_billing_account_path = staticmethod(
         FirewallClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(FirewallClient.common_folder_path)
     parse_common_folder_path = staticmethod(FirewallClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(FirewallClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         FirewallClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(FirewallClient.common_project_path)
     parse_common_project_path = staticmethod(FirewallClient.parse_common_project_path)
-
     common_location_path = staticmethod(FirewallClient.common_location_path)
     parse_common_location_path = staticmethod(FirewallClient.parse_common_location_path)
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -94,7 +88,7 @@ class FirewallAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -111,7 +105,7 @@ class FirewallAsyncClient:
 
     @property
     def transport(self) -> FirewallTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             FirewallTransport: The transport used by the client instance.
@@ -125,12 +119,12 @@ class FirewallAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, FirewallTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the firewall client.
+        """Instantiates the firewall client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -162,7 +156,6 @@ class FirewallAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = FirewallClient(
             credentials=credentials,
             transport=transport,
@@ -184,7 +177,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.ListIngressRulesRequest`):
                 The request object. Request message for
                 `Firewall.ListIngressRules`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -200,7 +192,6 @@ class FirewallAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.ListIngressRulesRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -249,7 +240,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest`):
                 The request object. Request message for
                 `Firewall.BatchUpdateIngressRules`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -261,7 +251,6 @@ class FirewallAsyncClient:
                 Response message for Firewall.UpdateAllIngressRules.
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.BatchUpdateIngressRulesRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -298,7 +287,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest`):
                 The request object. Request message for
                 `Firewall.CreateIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -314,7 +302,6 @@ class FirewallAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.CreateIngressRuleRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -351,7 +338,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetIngressRuleRequest`):
                 The request object. Request message for
                 `Firewall.GetIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -367,7 +353,6 @@ class FirewallAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetIngressRuleRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -404,7 +389,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest`):
                 The request object. Request message for
                 `Firewall.UpdateIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -420,7 +404,6 @@ class FirewallAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.UpdateIngressRuleRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -457,7 +440,6 @@ class FirewallAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest`):
                 The request object. Request message for
                 `Firewall.DeleteIngressRule`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -465,7 +447,6 @@ class FirewallAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DeleteIngressRuleRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
