@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation as gac_operation  # type: ignore
@@ -34,9 +32,8 @@ from google.cloud.appengine_admin_v1.services.instances import pagers
 from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import instance
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import InstancesTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import InstancesGrpcAsyncIOTransport
 from .client import InstancesClient
@@ -52,25 +49,20 @@ class InstancesAsyncClient:
 
     instance_path = staticmethod(InstancesClient.instance_path)
     parse_instance_path = staticmethod(InstancesClient.parse_instance_path)
-
     common_billing_account_path = staticmethod(
         InstancesClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         InstancesClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(InstancesClient.common_folder_path)
     parse_common_folder_path = staticmethod(InstancesClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(InstancesClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         InstancesClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(InstancesClient.common_project_path)
     parse_common_project_path = staticmethod(InstancesClient.parse_common_project_path)
-
     common_location_path = staticmethod(InstancesClient.common_location_path)
     parse_common_location_path = staticmethod(
         InstancesClient.parse_common_location_path
@@ -78,7 +70,8 @@ class InstancesAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -93,7 +86,7 @@ class InstancesAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -110,7 +103,7 @@ class InstancesAsyncClient:
 
     @property
     def transport(self) -> InstancesTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             InstancesTransport: The transport used by the client instance.
@@ -124,12 +117,12 @@ class InstancesAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, InstancesTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the instances client.
+        """Instantiates the instances client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -161,7 +154,6 @@ class InstancesAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = InstancesClient(
             credentials=credentials,
             transport=transport,
@@ -187,7 +179,6 @@ class InstancesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.ListInstancesRequest`):
                 The request object. Request message for
                 `Instances.ListInstances`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -203,7 +194,6 @@ class InstancesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.ListInstancesRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -246,7 +236,6 @@ class InstancesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetInstanceRequest`):
                 The request object. Request message for
                 `Instances.GetInstance`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -261,7 +250,6 @@ class InstancesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetInstanceRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -312,7 +300,6 @@ class InstancesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DeleteInstanceRequest`):
                 The request object. Request message for
                 `Instances.DeleteInstance`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -339,7 +326,6 @@ class InstancesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DeleteInstanceRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -363,7 +349,7 @@ class InstancesAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=ga_operation.OperationMetadataV1,
         )
 
@@ -393,7 +379,6 @@ class InstancesAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DebugInstanceRequest`):
                 The request object. Request message for
                 `Instances.DebugInstance`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -409,7 +394,6 @@ class InstancesAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DebugInstanceRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
