@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation as gac_operation  # type: ignore
@@ -36,10 +34,9 @@ from google.cloud.appengine_admin_v1.types import appengine
 from google.cloud.appengine_admin_v1.types import deploy
 from google.cloud.appengine_admin_v1.types import operation as ga_operation
 from google.cloud.appengine_admin_v1.types import version
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import VersionsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import VersionsGrpcAsyncIOTransport
 from .client import VersionsClient
@@ -59,24 +56,21 @@ class VersionsAsyncClient:
     parse_common_billing_account_path = staticmethod(
         VersionsClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(VersionsClient.common_folder_path)
     parse_common_folder_path = staticmethod(VersionsClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(VersionsClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         VersionsClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(VersionsClient.common_project_path)
     parse_common_project_path = staticmethod(VersionsClient.parse_common_project_path)
-
     common_location_path = staticmethod(VersionsClient.common_location_path)
     parse_common_location_path = staticmethod(VersionsClient.parse_common_location_path)
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -91,7 +85,7 @@ class VersionsAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -108,7 +102,7 @@ class VersionsAsyncClient:
 
     @property
     def transport(self) -> VersionsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             VersionsTransport: The transport used by the client instance.
@@ -122,12 +116,12 @@ class VersionsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, VersionsTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the versions client.
+        """Instantiates the versions client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -159,7 +153,6 @@ class VersionsAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = VersionsClient(
             credentials=credentials,
             transport=transport,
@@ -181,7 +174,6 @@ class VersionsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.ListVersionsRequest`):
                 The request object. Request message for
                 `Versions.ListVersions`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -197,7 +189,6 @@ class VersionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.ListVersionsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -242,7 +233,6 @@ class VersionsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.GetVersionRequest`):
                 The request object. Request message for
                 `Versions.GetVersion`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -257,7 +247,6 @@ class VersionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.GetVersionRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -294,7 +283,6 @@ class VersionsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.CreateVersionRequest`):
                 The request object. Request message for
                 `Versions.CreateVersion`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -310,7 +298,6 @@ class VersionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.CreateVersionRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -390,7 +377,6 @@ class VersionsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.UpdateVersionRequest`):
                 The request object. Request message for
                 `Versions.UpdateVersion`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -406,7 +392,6 @@ class VersionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.UpdateVersionRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -451,7 +436,6 @@ class VersionsAsyncClient:
             request (:class:`google.cloud.appengine_admin_v1.types.DeleteVersionRequest`):
                 The request object. Request message for
                 `Versions.DeleteVersion`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -478,7 +462,6 @@ class VersionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = appengine.DeleteVersionRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -502,7 +485,7 @@ class VersionsAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=ga_operation.OperationMetadataV1,
         )
 
